@@ -19,6 +19,7 @@ config_default: Dict = {
             "xbunker_password": "",
         },
         "Files": {
+            "variable_cache_file": "internal_variable_cache.yaml",
             "db_file": "download_history.sqlite",
             "errored_download_urls_file": "Errored_Download_URLs.csv",
             "errored_scrape_urls_file": "Errored_Scrape_URLs.csv",
@@ -65,6 +66,7 @@ config_default: Dict = {
         },
         "Ratelimiting": {
             "connection_timeout": 15,
+            "read_timeout": 300,
             "ratelimit": 50,
             "throttle": 0.5,
         },
@@ -85,6 +87,8 @@ config_default: Dict = {
             "max_concurrent_domains": 0,
             "max_concurrent_albums": 0,
             "max_concurrent_downloads_per_domain": 4,
+            "max_filename_length": 95,
+            "max_folder_name_length": 60,
             "output_errored_urls": False,
             "output_unsupported_urls": False,
             "proxy": "",
