@@ -1,20 +1,24 @@
+from __future__ import annotations
+
 import atexit
 import logging
 import sqlite3
-from pathlib import Path
-from typing import List, Optional
+from typing import TYPE_CHECKING, Optional, List
 
-from yarl import URL
+if TYPE_CHECKING:
+    from pathlib import Path
 
-from cyberdrop_dl.base_functions.data_classes import (
-    AlbumItem,
-    CascadeItem,
-    DomainItem,
-    MediaItem,
-)
+    from yarl import URL
+
+    from cyberdrop_dl.base_functions.data_classes import (
+        AlbumItem,
+        CascadeItem,
+        DomainItem,
+        MediaItem,
+    )
 
 
-async def get_db_path(url: URL, referer: str = None) -> str:
+async def get_db_path(url: URL, referer: str = "") -> str:
     """Gets the URL path to be put into the DB and checked from the DB"""
     url_path = url.path
 
@@ -37,8 +41,8 @@ class SQLHelper:
         self.ignore_history = ignore_history
         self.ignore_cache = ignore_cache
         self.download_history = download_history
-        self.conn = None
-        self.curs = None
+        self.conn = sqlite3.connect(self.download_history)
+        self.curs = self.conn.cursor()
 
         self.old_history = False
         # Close the sql connection when the program exits
@@ -46,11 +50,7 @@ class SQLHelper:
 
     async def sql_initialize(self) -> None:
         """Initializes the SQL connection, and makes sure necessary tables exist"""
-        self.conn = sqlite3.connect(self.download_history)
-        self.curs = self.conn.cursor()
-
         await self._check_old_history()
-
         await self._pre_allocate()
         await self._create_media_history()
         await self._create_coomeno_history()
@@ -245,7 +245,14 @@ class SQLHelper:
         sql_res = self.curs.fetchall()
         for row in sql_res:
             if row[7] == 1:
-                complete_row = row
+                if complete_row:
+                    if row[6] == original_filename:
+                        await self._remove_entry(url_path, complete_row[6])
+                        complete_row = row
+                    else:
+                        await self._remove_entry(url_path, row[6])
+                else:
+                    complete_row = row
             else:
                 if len(sql_res) < 2:
                     await self._update_row_original_filename(url_path, original_filename)
@@ -269,6 +276,6 @@ class SQLHelper:
             self.conn.commit()
             self.conn.close()
         except Exception as e:
-            logging.debug("Failed to close sqlite database connection: %s", str(e))
+            logging.debug("Failed to close sqlite database connection: %s", e)
         else:
             logging.debug("Successfully closed sqlite database connection")
