@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import asyncio
-import contextlib
 import functools
 import json
 import logging
@@ -44,8 +43,10 @@ def scrape_limit(func):
 
 class Client:
     """Creates a 'client' that can be referenced by scraping or download sessions"""
-    def __init__(self, ratelimit: int, throttle: float, secure: bool, connect_timeout: int, user_agent: str):
+    def __init__(self, ratelimit: int, throttle: float, secure: bool, connect_timeout: int, read_timeout: int,
+                 user_agent: str):
         self.connect_timeout = connect_timeout
+        self.read_timeout = read_timeout
         self.ratelimit = ratelimit
         self.throttle = throttle
         self.simultaneous_session_limit = asyncio.Semaphore(50)
@@ -61,8 +62,8 @@ class ScrapeSession:
         self.client = client
         self.rate_limiter = AsyncLimiter(self.client.ratelimit, 1)
         self.headers = {"user-agent": client.user_agent}
-        self.timeouts = aiohttp.ClientTimeout(total=self.client.connect_timeout + 45,
-                                              connect=self.client.connect_timeout, sock_read=45)
+        self.timeouts = aiohttp.ClientTimeout(total=self.client.connect_timeout + 60,
+                                              connect=self.client.connect_timeout)
         self.client_session = aiohttp.ClientSession(headers=self.headers, raise_for_status=True,
                                                     cookie_jar=self.client.cookies, timeout=self.timeouts)
 
@@ -120,7 +121,8 @@ class DownloadSession:
     def __init__(self, client: Client):
         self.client = client
         self.headers = {"user-agent": client.user_agent}
-        self.timeouts = aiohttp.ClientTimeout(total=None, connect=self.client.connect_timeout, sock_read=None)
+        self.timeouts = aiohttp.ClientTimeout(total=self.client.read_timeout + self.client.connect_timeout,
+                                              connect=self.client.connect_timeout, sock_read=self.client.read_timeout)
         self.client_session = aiohttp.ClientSession(headers=self.headers, raise_for_status=True,
                                                     cookie_jar=self.client.cookies, timeout=self.timeouts)
         self.throttle_times: Dict[str, float] = {}
