@@ -1,48 +1,53 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from yarl import URL
 
 from ..base_functions.base_functions import (
     check_direct,
-    get_filename_and_ext,
+    create_media_item,
     log,
     logger,
     make_title_safe,
 )
-from ..base_functions.data_classes import AlbumItem, MediaItem
-from ..base_functions.error_classes import NoExtensionFailure, InvalidContentTypeFailure
-from ..base_functions.sql_helper import SQLHelper
-from ..client.client import ScrapeSession
+from ..base_functions.data_classes import AlbumItem
+from ..base_functions.error_classes import InvalidContentTypeFailure, NoExtensionFailure
+
+if TYPE_CHECKING:
+    from ..base_functions.base_functions import ErrorFileWriter
+    from ..base_functions.sql_helper import SQLHelper
+    from ..client.client import ScrapeSession
 
 
 class CyberdropCrawler:
-    def __init__(self, *, include_id=False, quiet: bool, SQL_Helper: SQLHelper):
+    def __init__(self, *, include_id=False, quiet: bool, SQL_Helper: SQLHelper, error_writer: ErrorFileWriter):
         self.include_id = include_id
         self.SQL_Helper = SQL_Helper
         self.quiet = quiet
 
+        self.error_writer = error_writer
+
     async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Cyberdrop scraper"""
         album_obj = AlbumItem("Loose Cyberdrop Files", [])
 
-        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Starting: {url}", quiet=self.quiet, style="green")
         if await check_direct(url):
-            complete = await self.SQL_Helper.check_complete_singular("cyberdrop", url)
-            filename, ext = await get_filename_and_ext(url.name)
-            media = MediaItem(url, url, complete, filename, ext, filename)
+            media = await create_media_item(url, url, self.SQL_Helper, "cyberdrop")
             await album_obj.add_media(media)
             await self.SQL_Helper.insert_album("cyberdrop", URL(""), album_obj)
-            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+            log(f"Finished: {url}", quiet=self.quiet, style="green")
             return album_obj
 
         try:
             try:
                 soup = await session.get_BS4(url)
             except InvalidContentTypeFailure:
-                complete = await self.SQL_Helper.check_complete_singular("cyberdrop", url)
-                filename, ext = await get_filename_and_ext(url.name)
-                media = MediaItem(url, url, complete, filename, ext, filename)
+                media = await create_media_item(url, url, self.SQL_Helper, "cyberdrop")
                 await album_obj.add_media(media)
                 await self.SQL_Helper.insert_album("cyberdrop", URL(""), album_obj)
-                await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+                log(f"Finished: {url}", quiet=self.quiet, style="green")
                 return album_obj
 
             title = soup.select_one("h1[id=title]").get_text()
@@ -58,21 +63,18 @@ class CyberdropCrawler:
             for link in links:
                 link = URL(link.get('href'))
                 try:
-                    filename, ext = await get_filename_and_ext(link.name)
+                    media = await create_media_item(link, url, self.SQL_Helper, "cyberdrop")
                 except NoExtensionFailure:
-                    logger.debug("Couldn't get extension for %s", str(link))
+                    logger.debug("Couldn't get extension for %s", link)
                     continue
 
-                complete = await self.SQL_Helper.check_complete_singular("cyberdrop", link)
-                media = MediaItem(link, url, complete, filename, ext, filename)
                 await album_obj.add_media(media)
 
         except Exception as e:
-            logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
-            logger.debug(e)
+            logger.debug("Error encountered while handling %s", url, exc_info=True)
+            await self.error_writer.write_errored_scrape(url, e, self.quiet)
             return album_obj
 
         await self.SQL_Helper.insert_album("cyberdrop", url, album_obj)
-        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Finished: {url}", quiet=self.quiet, style="green")
         return album_obj
