@@ -1,26 +1,37 @@
-from typing import Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional
 
 from yarl import URL
 
-from ..base_functions.base_functions import get_filename_and_ext, log, logger, make_title_safe
-from ..base_functions.data_classes import AlbumItem, MediaItem
+from ..base_functions.base_functions import create_media_item, log, logger, make_title_safe
+from ..base_functions.data_classes import AlbumItem
 from ..base_functions.error_classes import NoExtensionFailure
-from ..base_functions.sql_helper import SQLHelper
-from ..client.client import ScrapeSession
+
+if TYPE_CHECKING:
+    from ..base_functions.base_functions import ErrorFileWriter
+    from ..base_functions.data_classes import MediaItem
+    from ..base_functions.sql_helper import SQLHelper
+    from ..client.client import ScrapeSession
 
 
 class FapelloCrawler:
-    def __init__(self, *, quiet: bool, SQL_Helper: SQLHelper):
+    def __init__(self, *, quiet: bool, SQL_Helper: SQLHelper, error_writer: ErrorFileWriter):
         self.quiet = quiet
         self.SQL_Helper = SQL_Helper
 
+        self.error_writer = error_writer
+
     async def fetch(self, session: ScrapeSession, url: URL) -> Optional[AlbumItem]:
         """Basic director for fapello"""
-        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Starting: {url}", quiet=self.quiet, style="green")
+
+        if not str(url).endswith("/"):
+            url = url / ""
 
         album_obj = await self.parse_profile(session, url)
 
-        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Finished: {url}", quiet=self.quiet, style="green")
         return album_obj
 
     async def parse_profile(self, session: ScrapeSession, url: URL) -> Optional[AlbumItem]:
@@ -40,7 +51,7 @@ class FapelloCrawler:
             content_section = soup.select_one("div[id=content]")
             posts = content_section.select("a")
             for post in posts:
-                link = post.get('href')
+                link = URL(post.get('href'))
                 if link:
                     media_items = await self.parse_post(session, link)
                     for media in media_items:
@@ -55,16 +66,15 @@ class FapelloCrawler:
             return album_obj
 
         except Exception as e:
-            logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
-            logger.debug(e)
+            logger.debug("Error encountered while handling %s", url, exc_info=True)
+            await self.error_writer.write_errored_scrape(url, e, self.quiet)
             return None
 
-    async def parse_post(self, session: ScrapeSession, url: URL):
-        """Parses posts, returns list of media_items"""
+    async def parse_post(self, session: ScrapeSession, url: URL) -> list[MediaItem]:
+        """Parses posts, returns list of MediaItem"""
+        results = []
         try:
             soup = await session.get_BS4(url)
-            results = []
 
             content_section = soup.select_one('div[class="flex justify-between items-center"]')
 
@@ -72,28 +82,23 @@ class FapelloCrawler:
             for image in images:
                 download_link = URL(image.get('src'))
                 try:
-                    filename, ext = await get_filename_and_ext(download_link.name)
+                    media_item = await create_media_item(download_link, url, self.SQL_Helper, "fapello")
                 except NoExtensionFailure:
-                    logger.debug("Couldn't get extension for %s", str(download_link))
+                    logger.debug("Couldn't get extension for %s", download_link)
                     continue
-                complete = await self.SQL_Helper.check_complete_singular("fapello", download_link)
-                results.append(MediaItem(download_link, url, complete, filename, ext, filename))
+                results.append(media_item)
 
             videos = content_section.select("source")
             for video in videos:
                 download_link = URL(video.get('src'))
                 try:
-                    filename, ext = await get_filename_and_ext(download_link.name)
+                    media_item = await create_media_item(download_link, url, self.SQL_Helper, "fapello")
                 except NoExtensionFailure:
-                    logger.debug("Couldn't get extension for %s", str(download_link))
+                    logger.debug("Couldn't get extension for %s", download_link)
                     continue
-                complete = await self.SQL_Helper.check_complete_singular("fapello", download_link)
-                results.append(MediaItem(download_link, url, complete, filename, ext, filename))
-
-            return results
-
+                results.append(media_item)
         except Exception as e:
-            logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
-            logger.debug(e)
-            return
+            logger.debug("Error encountered while handling %s", url, exc_info=True)
+            await self.error_writer.write_errored_scrape(url, e, self.quiet)
+
+        return results
