@@ -1,35 +1,42 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from yarl import URL
 
 from ..base_functions.base_functions import (
     check_direct,
-    get_filename_and_ext,
+    create_media_item,
     log,
     logger,
     make_title_safe,
 )
-from ..base_functions.data_classes import AlbumItem, MediaItem
+from ..base_functions.data_classes import AlbumItem
 from ..base_functions.error_classes import NoExtensionFailure
-from ..base_functions.sql_helper import SQLHelper
-from ..client.client import ScrapeSession
+
+if TYPE_CHECKING:
+    from ..base_functions.base_functions import ErrorFileWriter
+    from ..base_functions.sql_helper import SQLHelper
+    from ..client.client import ScrapeSession
 
 
 class LoveFapCrawler:
-    def __init__(self, quiet: bool, SQL_Helper: SQLHelper):
+    def __init__(self, quiet: bool, SQL_Helper: SQLHelper, error_writer: ErrorFileWriter):
         self.SQL_Helper = SQL_Helper
         self.quiet = quiet
 
+        self.error_writer = error_writer
+
     async def fetch(self, session: ScrapeSession, url: URL) -> AlbumItem:
         """Director for lovefap scraping"""
         album_obj = AlbumItem("Loose LoveFap Files", [])
 
-        await log(f"Starting: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Starting: {url}", quiet=self.quiet, style="green")
         if await check_direct(url):
-            complete = await self.SQL_Helper.check_complete_singular("lovefap", url)
-            filename, ext = await get_filename_and_ext(url.name)
-            media = MediaItem(url, url, complete, filename, ext, filename)
+            media = await create_media_item(url, url, self.SQL_Helper, "lovefap")
             await album_obj.add_media(media)
             await self.SQL_Helper.insert_album("lovefap", URL(""), album_obj)
-            await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+            log(f"Finished: {url}", quiet=self.quiet, style="green")
             return album_obj
 
         try:
@@ -39,16 +46,15 @@ class LoveFapCrawler:
                 await self.fetch_album(session, url, album_obj)
 
         except Exception as e:
-            logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            await log(f"Error: {str(url)}", quiet=self.quiet, style="red")
-            logger.debug(e)
+            logger.debug("Error encountered while handling %s", url, exc_info=True)
+            await self.error_writer.write_errored_scrape(url, e, self.quiet)
             return album_obj
 
         await self.SQL_Helper.insert_album("lovefap", url, album_obj)
-        await log(f"Finished: {str(url)}", quiet=self.quiet, style="green")
+        log(f"Finished: {url}", quiet=self.quiet, style="green")
         return album_obj
 
-    async def fetch_album(self, session: ScrapeSession, url: URL, album_obj: AlbumItem):
+    async def fetch_album(self, session: ScrapeSession, url: URL, album_obj: AlbumItem) -> None:
         """Gets media_items for albums, and adds them to the Album_obj"""
         soup = await session.get_BS4(url)
 
@@ -69,27 +75,23 @@ class LoveFapCrawler:
                 await self.fetch_video(session, url, album_obj)
             else:
                 try:
-                    filename, ext = await get_filename_and_ext(link.name)
+                    media = await create_media_item(link, url, self.SQL_Helper, "lovefap")
                 except NoExtensionFailure:
-                    logger.debug("Couldn't get extension for %s", str(link))
+                    logger.debug("Couldn't get extension for %s", link)
                     continue
 
-                complete = await self.SQL_Helper.check_complete_singular("lovefap", link)
-                media = MediaItem(link, url, complete, filename, ext, filename)
                 await album_obj.add_media(media)
 
-    async def fetch_video(self, session: ScrapeSession, url: URL, album_obj: AlbumItem):
+    async def fetch_video(self, session: ScrapeSession, url: URL, album_obj: AlbumItem) -> None:
         """Gets media_items for video links"""
         soup = await session.get_BS4(url)
         video = soup.select_one("video[id=main-video] source")
         if video:
             link = URL(video.get("src"))
             try:
-                filename, ext = await get_filename_and_ext(link.name)
+                media = await create_media_item(link, url, self.SQL_Helper, "lovefap")
             except NoExtensionFailure:
-                logger.debug("Couldn't get extension for %s", str(link))
+                logger.debug("Couldn't get extension for %s", link)
                 return
 
-            complete = await self.SQL_Helper.check_complete_singular("lovefap", link)
-            media = MediaItem(link, url, complete, filename, ext, filename)
             await album_obj.add_media(media)
