@@ -5,13 +5,19 @@ import contextlib
 import logging
 import re
 from pathlib import Path
-from typing import Dict, List
+from typing import Dict, List, Tuple
 
 import aiofiles
 import aiorun as aiorun
 from yarl import URL
 
-from cyberdrop_dl.base_functions.base_functions import ErrorFileWriter, clear, log, purge_dir
+from cyberdrop_dl.base_functions.base_functions import (
+    CacheManager,
+    ErrorFileWriter,
+    clear,
+    log,
+    purge_dir,
+)
 from cyberdrop_dl.base_functions.config_manager import document_args, run_args
 from cyberdrop_dl.base_functions.config_schema import config_default
 from cyberdrop_dl.base_functions.sorting_functions import Sorter
@@ -23,6 +29,7 @@ from cyberdrop_dl.downloader.old_downloaders import old_download_forums
 from cyberdrop_dl.scraper.Scraper import ScrapeMapper
 
 from . import __version__ as VERSION
+from .base_functions.base_functions import MAX_NAME_LENGTHS
 from .base_functions.data_classes import ForumItem, SkipData
 
 
@@ -40,6 +47,7 @@ def parse_args() -> argparse.Namespace:
     path_opts.add_argument("-o", "--output-folder", type=Path, help="folder to download files to (default: %(default)s)", default=config_group["output_folder"])
 
     path_opts.add_argument("--config-file", type=Path, help="config file to read arguments from (default: %(default)s)", default="config.yaml")
+    path_opts.add_argument("--variable-cache-file", type=Path, help="internal variable cache file to read from and write to (default: %(default)s)", default=config_group["variable_cache_file"])
     path_opts.add_argument("--db-file", type=Path, help="history database file to write to (default: %(default)s)", default=config_group["db_file"])
     path_opts.add_argument("--errored-download-urls-file", type=Path, default=config_group["errored_download_urls_file"], help="csv file to write failed download information to (default: %(default)s)")
     path_opts.add_argument("--errored-scrape-urls-file", type=Path, default=config_group["errored_scrape_urls_file"], help="csv file to write failed scrape information to (default: %(default)s)")
@@ -78,6 +86,8 @@ def parse_args() -> argparse.Namespace:
     runtime_opts.add_argument("--max-concurrent-domains", type=int, default=config_group["max_concurrent_domains"], help="Number of domains to download simultaneously (default: %(default)s)")
     runtime_opts.add_argument("--max-concurrent-albums", type=int, default=config_group["max_concurrent_albums"], help="Number of albums to download simultaneously (default: %(default)s)")
     runtime_opts.add_argument("--max-concurrent-downloads-per-domain", type=int, default=config_group["max_concurrent_downloads_per_domain"], help="Number of simultaneous downloads per domain (default: %(default)s)")
+    runtime_opts.add_argument("--max-filename-length", type=int, default=config_group["max_filename_length"], help="maximum filename length (default: %(default)s)")
+    runtime_opts.add_argument("--max-folder-name-length", type=int, default=config_group["max_folder_name_length"], help="maximum folder name length (default: %(default)s)")
     runtime_opts.add_argument("--skip-download-mark-completed", help="sets the scraped files as downloaded without downloading", action="store_true")
     runtime_opts.add_argument("--output-errored-urls", help="sets the failed urls to be output to the errored urls file", action="store_true")
     runtime_opts.add_argument("--output-unsupported-urls", help="sets the unsupported urls to be output to the unsupported urls file", action="store_true")
@@ -99,6 +109,7 @@ def parse_args() -> argparse.Namespace:
     config_group = config_data["Ratelimiting"]
     ratelimit_opts = parser.add_argument_group("Ratelimiting options")
     ratelimit_opts.add_argument("--connection-timeout", type=int, default=config_group["connection_timeout"], help="number of seconds to wait attempting to connect to a URL during the downloading phase (default: %(default)s)")
+    ratelimit_opts.add_argument("--read-timeout", type=int, default=config_group["read_timeout"], help="number of seconds to wait attempting to read all file data during the downloading phase (default: %(default)s)")
     ratelimit_opts.add_argument("--ratelimit", type=int, default=config_group["ratelimit"], help="this applies to requests made in the program during scraping, the number you provide is in requests/seconds (default: %(default)s)")
     ratelimit_opts.add_argument("--throttle", type=int, default=config_group["throttle"], help="this is a throttle between requests during the downloading phase, the number is in seconds (default: %(default)s)")
 
@@ -152,7 +163,7 @@ def parse_args() -> argparse.Namespace:
     return parser.parse_args()
 
 
-async def file_management(args: Dict, links: List) -> ErrorFileWriter:
+async def file_management(args: Dict, links: List) -> Tuple[ErrorFileWriter, CacheManager]:
     """We handle file defaults here (resetting and creation)"""
     input_file = args['Files']['input_file']
     if not input_file.is_file() and not links:
@@ -191,7 +202,10 @@ async def file_management(args: Dict, links: List) -> ErrorFileWriter:
         errored_urls.touch()
         await error_writer.write_errored_scrape_header()
 
-    return error_writer
+    cache_manager = CacheManager(args['Files']['variable_cache_file'])
+    await cache_manager.load()
+
+    return error_writer, cache_manager
 
 
 async def regex_links(urls: List) -> List:
@@ -262,7 +276,10 @@ async def director(args: Dict, links: List) -> None:
     await clear()
     await document_args(args)
     log(f"We are running version {VERSION} of Cyberdrop Downloader")
-    error_writer = await file_management(args, links)
+    error_writer, cache_manager = await file_management(args, links)
+
+    MAX_NAME_LENGTHS["FILE"] = args["Runtime"]["max_filename_length"]
+    MAX_NAME_LENGTHS["FOLDER"] = args["Runtime"]["max_folder_name_length"]
 
     if not await check_free_space(args['Runtime']['required_free_space'], args['Files']['output_folder']):
         log("Not enough free space to continue. You can change the required space required using --required-free-space.", style="red")
@@ -271,9 +288,9 @@ async def director(args: Dict, links: List) -> None:
     links = await consolidate_links(args, links)
     client = Client(args['Ratelimiting']['ratelimit'], args['Ratelimiting']['throttle'],
                     args['Runtime']['allow_insecure_connections'], args["Ratelimiting"]["connection_timeout"],
-                    args['Runtime']['user_agent'])
+                    args["Ratelimiting"]["read_timeout"], args['Runtime']['user_agent'])
     SQL_Helper = SQLHelper(args['Ignore']['ignore_history'], args['Ignore']['ignore_cache'], args['Files']['db_file'])
-    Scraper = ScrapeMapper(args, client, SQL_Helper, False, error_writer)
+    Scraper = ScrapeMapper(args, client, SQL_Helper, False, error_writer, cache_manager)
 
     await SQL_Helper.sql_initialize()
 
@@ -316,7 +333,9 @@ async def director(args: Dict, links: List) -> None:
     await check_outdated(client)
     log("\nIf you enjoy using this program, please consider buying the developer a coffee :)"
         "\nhttps://www.buymeacoffee.com/juleswinnft", style="green")
-    asyncio.get_event_loop().stop()
+
+    with contextlib.suppress(RuntimeError):
+        asyncio.get_event_loop().stop()
 
 
 def main(args=None):
@@ -339,14 +358,8 @@ def main(args=None):
         loop = asyncio.new_event_loop()
         asyncio.set_event_loop(loop)
 
-        def handler(loop, context):
-            # https://docs.python.org/3/library/asyncio-eventloop.html#asyncio.loop.call_exception_handler
-            log(f'Stopping loop due to error: {context["exception"]}', quiet=True)
-            loop.stop()
-
-        loop.set_exception_handler(handler)
-        loop.create_task(director(args, links))
-        aiorun.run(loop=loop)
+        aiorun.run(director(args, links))
+        exit(0)
 
 
 if __name__ == '__main__':
